{% load twitter_bootstrap %}

{% if field|is_checkbox %}
    <label class="checkbox" for="{{ field.auto_id }}">
        {{ field }} {{ field.label }}
    </label>

{% elif field|is_radio %}
    {% for radio in field %}
    <label class="radio">
        {{ radio.tag }} {{ radio.choice_label }}
    </label>
    {% endfor %}
{% else %}
    <label class="control-label" for="{{ field.auto_id }}">{{ field.label }}</label>
    {{ field }}
{% endif %}

{% for error in field.errors %}
    <span class="help-inline">{{ error }}</span>
{% endfor %}

{% if field.help_text %}
    <p class="help-block">{{ field.help_text|safe }}</p>
{% endif %}
